@@ -7,6 +7,7 @@
 #include "core/fpdfapi/font/cpdf_cidfont.h"
 
 #include <algorithm>
+#include <array>
 #include <limits>
 #include <utility>
 #include <vector>
@@ -31,27 +32,34 @@
 #include "core/fxcrt/fx_safe_types.h"
 #include "core/fxcrt/fx_unicode.h"
 #include "core/fxcrt/span.h"
+#include "core/fxcrt/span_util.h"
 #include "core/fxcrt/stl_util.h"
 #include "core/fxge/fx_font.h"
 
 namespace {
 
-constexpr FX_CodePage kCharsetCodePages[CIDSET_NUM_SETS] = {
+struct LowHighVal {
+  int low;
+  int high;
+  int val;
+};
+
+struct LowHighValXY : LowHighVal {
+  int x;
+  int y;
+};
+
+bool IsMetricForCID(const LowHighVal& val, uint16_t cid) {
+  return val.low <= cid && cid <= val.high;
+}
+
+constexpr std::array<FX_CodePage, CIDSET_NUM_SETS> kCharsetCodePages = {
     FX_CodePage::kDefANSI,
     FX_CodePage::kChineseSimplified,
     FX_CodePage::kChineseTraditional,
     FX_CodePage::kShiftJIS,
     FX_CodePage::kHangul,
-    FX_CodePage::kUTF16LE};
-
-struct CIDTransform {
-  uint16_t cid;
-  uint8_t a;
-  uint8_t b;
-  uint8_t c;
-  uint8_t d;
-  uint8_t e;
-  uint8_t f;
+    FX_CodePage::kUTF16LE,
 };
 
 constexpr CIDTransform kJapan1VerticalCIDs[] = {
@@ -211,10 +219,6 @@ void UseCIDCharmap(const RetainPtr<CFX_Face>& face, CIDCoding coding) {
   }
 }
 
-bool IsMetricForCID(const int* pEntry, uint16_t cid) {
-  return pEntry[0] <= cid && pEntry[1] >= cid;
-}
-
 void LoadMetricsArray(RetainPtr<const CPDF_Array> pArray,
                       std::vector<int>* result,
                       int nElements) {
@@ -323,15 +327,18 @@ wchar_t CPDF_CIDFont::GetUnicodeFromCharCode(uint32_t charcode) const {
     return m_pCID2UnicodeMap->UnicodeFromCID(CIDFromCharCode(charcode));
 
 #if BUILDFLAG(IS_WIN)
-  wchar_t unicode;
-  int charsize = 1;
-  if (charcode > 255) {
-    charcode = (charcode % 256) * 256 + (charcode / 256);
-    charsize = 2;
+  uint8_t sequence[2] = {};
+  const int charsize = charcode < 256 ? 1 : 2;
+  if (charsize == 1) {
+    sequence[0] = charcode;
+  } else {
+    sequence[0] = charcode / 256;
+    sequence[1] = charcode % 256;
   }
+  wchar_t unicode;
   size_t ret = FX_MultiByteToWideChar(
       kCharsetCodePages[static_cast<size_t>(m_pCMap->GetCoding())],
-      ByteStringView(reinterpret_cast<const char*>(&charcode), charsize),
+      ByteStringView(pdfium::make_span(sequence).first(charsize)),
       pdfium::span_from_ref(unicode));
   return ret == 1 ? unicode : 0;
 #else
@@ -378,8 +385,8 @@ uint32_t CPDF_CIDFont::CharCodeFromUnicode(wchar_t unicode) const {
   uint8_t buffer[32];
   size_t ret = FX_WideCharToMultiByte(
       kCharsetCodePages[static_cast<size_t>(m_pCMap->GetCoding())],
-      WideStringView(&unicode, 1),
-      pdfium::make_span(reinterpret_cast<char*>(buffer), 4u));
+      WideStringView(unicode),
+      pdfium::as_writable_chars(pdfium::make_span(buffer).first(4u)));
   if (ret == 1)
     return buffer[0];
   if (ret == 2)
@@ -522,14 +529,14 @@ FX_RECT CPDF_CIDFont::GetCharBBox(uint32_t charcode) {
   }
   if (!m_pFontFile && m_Charset == CIDSET_JAPAN1) {
     uint16_t cid = CIDFromCharCode(charcode);
-    const uint8_t* pTransform = GetCIDTransform(cid);
+    const CIDTransform* pTransform = GetCIDTransform(cid);
     if (pTransform && !bVert) {
-      CFX_Matrix matrix(CIDTransformToFloat(pTransform[0]),
-                        CIDTransformToFloat(pTransform[1]),
-                        CIDTransformToFloat(pTransform[2]),
-                        CIDTransformToFloat(pTransform[3]),
-                        CIDTransformToFloat(pTransform[4]) * 1000,
-                        CIDTransformToFloat(pTransform[5]) * 1000);
+      CFX_Matrix matrix(CIDTransformToFloat(pTransform->a),
+                        CIDTransformToFloat(pTransform->b),
+                        CIDTransformToFloat(pTransform->c),
+                        CIDTransformToFloat(pTransform->d),
+                        CIDTransformToFloat(pTransform->e) * 1000,
+                        CIDTransformToFloat(pTransform->f) * 1000);
       rect = matrix.TransformRect(CFX_FloatRect(rect)).GetOuterRect();
     }
   }
@@ -540,52 +547,45 @@ FX_RECT CPDF_CIDFont::GetCharBBox(uint32_t charcode) {
 }
 
 int CPDF_CIDFont::GetCharWidthF(uint32_t charcode) {
-  if (charcode < 0x80 && m_bAnsiWidthsFixed)
+  if (charcode < 0x80 && m_bAnsiWidthsFixed) {
     return (charcode >= 32 && charcode < 127) ? 500 : 0;
-
+  }
   uint16_t cid = CIDFromCharCode(charcode);
-  size_t size = m_WidthList.size();
-  const int* pList = m_WidthList.data();
-  for (size_t i = 0; i < size; i += 3) {
-    const int* pEntry = pList + i;
-    if (IsMetricForCID(pEntry, cid))
-      return pEntry[2];
+  auto lhv_span =
+      fxcrt::reinterpret_span<const LowHighVal>(pdfium::make_span(m_WidthList));
+  for (const auto& lhv : lhv_span) {
+    if (IsMetricForCID(lhv, cid)) {
+      return lhv.val;
+    }
   }
   return m_DefaultWidth;
 }
 
 int16_t CPDF_CIDFont::GetVertWidth(uint16_t cid) const {
-  size_t vertsize = m_VertMetrics.size() / 5;
-  if (vertsize) {
-    const int* pTable = m_VertMetrics.data();
-    for (size_t i = 0; i < vertsize; i++) {
-      const int* pEntry = pTable + (i * 5);
-      if (IsMetricForCID(pEntry, cid))
-        return static_cast<int16_t>(pEntry[2]);
+  auto lhvxy_span = fxcrt::reinterpret_span<const LowHighValXY>(
+      pdfium::make_span(m_VertMetrics));
+  for (const auto& lhvxy : lhvxy_span) {
+    if (IsMetricForCID(lhvxy, cid)) {
+      return lhvxy.val;
     }
   }
   return m_DefaultW1;
 }
 
 CFX_Point16 CPDF_CIDFont::GetVertOrigin(uint16_t cid) const {
-  size_t vertsize = m_VertMetrics.size() / 5;
-  if (vertsize) {
-    const int* pTable = m_VertMetrics.data();
-    for (size_t i = 0; i < vertsize; i++) {
-      const int* pEntry = pTable + (i * 5);
-      if (IsMetricForCID(pEntry, cid)) {
-        return {static_cast<int16_t>(pEntry[3]),
-                static_cast<int16_t>(pEntry[4])};
-      }
+  auto lhvxy_span = fxcrt::reinterpret_span<const LowHighValXY>(
+      pdfium::make_span(m_VertMetrics));
+  for (const auto& lhvxy : lhvxy_span) {
+    if (IsMetricForCID(lhvxy, cid)) {
+      return {static_cast<int16_t>(lhvxy.x), static_cast<int16_t>(lhvxy.y)};
     }
   }
   int width = m_DefaultWidth;
-  size_t size = m_WidthList.size();
-  const int* pList = m_WidthList.data();
-  for (size_t i = 0; i < size; i += 3) {
-    const int* pEntry = pList + i;
-    if (IsMetricForCID(pEntry, cid)) {
-      width = pEntry[2];
+  auto lhv_span =
+      fxcrt::reinterpret_span<const LowHighVal>(pdfium::make_span(m_WidthList));
+  for (const auto& lhv : lhv_span) {
+    if (IsMetricForCID(lhv, cid)) {
+      width = lhv.val;
       break;
     }
   }
@@ -799,8 +799,8 @@ size_t CPDF_CIDFont::CountChar(ByteStringView pString) const {
   return m_pCMap->CountChar(pString);
 }
 
-int CPDF_CIDFont::AppendChar(char* str, uint32_t charcode) const {
-  return m_pCMap->AppendChar(str, charcode);
+void CPDF_CIDFont::AppendChar(ByteString* str, uint32_t charcode) const {
+  m_pCMap->AppendChar(str, charcode);
 }
 
 bool CPDF_CIDFont::IsUnicodeCompatible() const {
@@ -810,12 +810,12 @@ bool CPDF_CIDFont::IsUnicodeCompatible() const {
 }
 
 void CPDF_CIDFont::LoadSubstFont() {
-  FX_SAFE_INT32 safeStemV(m_StemV);
-  safeStemV *= 5;
-  m_Font.LoadSubst(m_BaseFontName, m_FontType == CIDFontType::kTrueType,
-                   m_Flags, safeStemV.ValueOrDefault(FXFONT_FW_NORMAL),
-                   m_ItalicAngle, kCharsetCodePages[m_Charset],
-                   IsVertWriting());
+  FX_SAFE_INT32 safe_stem_v(m_StemV);
+  safe_stem_v *= 5;
+  m_Font.LoadSubst(
+      m_BaseFontName, m_FontType == CIDFontType::kTrueType, m_Flags,
+      safe_stem_v.ValueOrDefault(pdfium::kFontWeightNormal), m_ItalicAngle,
+      kCharsetCodePages[m_Charset], IsVertWriting());
 }
 
 // static
@@ -841,7 +841,7 @@ void CPDF_CIDFont::LoadGB2312() {
   m_bAnsiWidthsFixed = true;
 }
 
-const uint8_t* CPDF_CIDFont::GetCIDTransform(uint16_t cid) const {
+const CIDTransform* CPDF_CIDFont::GetCIDTransform(uint16_t cid) const {
   if (m_Charset != CIDSET_JAPAN1 || m_pFontFile)
     return nullptr;
 
@@ -851,6 +851,5 @@ const uint8_t* CPDF_CIDFont::GetCIDTransform(uint16_t cid) const {
       pBegin, pEnd, cid,
       [](const CIDTransform& entry, uint16_t cid) { return entry.cid < cid; });
 
-  return (pTransform < pEnd && cid == pTransform->cid) ? &pTransform->a
-                                                       : nullptr;
+  return pTransform < pEnd && cid == pTransform->cid ? pTransform : nullptr;
 }
