@@ -1,14 +1,14 @@
 // Copyright 2019 Google LLC.
 // Use of this source code is governed by a BSD-style license that can be found in the LICENSE file.
 #include "tools/fiddle/examples.h"
-REG_FIDDLE(Pixmap_addr32_2, 256, 256, true, 0) {
+REG_FIDDLE(Pixmap_addr64_2, 256, 256, true, 0) {
 void draw(SkCanvas* canvas) {
     const int w = 4;
     const int h = 4;
-    uint32_t storage[w * h];
-    SkPixmap pixmap(SkImageInfo::Make(w, h, kRGBA_8888_SkColorType, kPremul_SkAlphaType),
+    uint64_t storage[w * h];
+    SkPixmap pixmap(SkImageInfo::Make(w, h, kRGBA_F16_SkColorType, kPremul_SkAlphaType),
                     storage, w * sizeof(storage[0]));
-    SkDebugf("pixmap.addr32(1, 2) %c= &storage[1 + 2 * w]\n",
-              pixmap.addr32(1, 2)  == &storage[1 + 2 * w] ? '=' : '!');
+    SkDebugf("pixmap.addr64(1, 2) %c= &storage[1 + 2 * w]\n",
+              pixmap.addr64(1, 2)  == &storage[1 + 2 * w] ? '=' : '!');
 }
 }  // END FIDDLE
